
import os
import re
import requests

from dotenv import load_dotenv 

from requests.adapters import HTTPAdapter
from requests.packages.urllib3.util.retry import Retry

retry_strategy = Retry(
        total=8,
        status_forcelist=[429, 500, 502, 503, 504],
        allowed_methods=["HEAD", "GET", "OPTIONS"]
    )

load_dotenv()

__version__ = "0.2"
__author__ = "Massimiliano Stucchi"
__author_email__ = "max@stucchi.ch"
__copyright__ = "Copyright 2023, Massimiliano Stucchi"
__license__ = "BSD"
__status__ = "Stable"
__url__ = "https://github.com/stucchimax/asn_info"

class Asns:
    def __init__(self):
        
        self.asns = {}

    def load_asn_data(self, add_manrs_data = False):

        url = "https://ftp.ripe.net/ripe/asnames/asn.txt"

        q = requests.Session()

        p = q.get(url, timeout=20)

        for line in p.iter_lines():
            split_line = line.decode().split(", ")
            
            try:
                country = split_line[1]
                split_line.pop(1)
            except:
                country = "ZZ"

            as_details = split_line[0].split()

            asn = int(as_details[0])
            
            as_details.pop(0)
            
            try:
                as_name = ' '.join(as_details)
            except:
                as_name = "None/Reserved"

            self.asns[asn] = {"country": country, "as_name": as_name}
        
        if add_manrs_data == True:
            self.manrs_data = True
            self.load_manrs_asn_data()
        else:
            self.manrs_data = False

    def load_manrs_asn_data(self):

        url = "https://api.manrs.org/asns/info"

        headers = {
                "Accept": "application/json",
                "Authorization": "Bearer {}".format(os.getenv("MANRS_API_KEY"))
                }
        q = requests.Session()

        p = q.get(url, timeout=20, headers=headers)

        manrs_asns = p.json()
        
        for asn in manrs_asns['asns']:
            if asn['number'] in self.asns:
                self.asns[asn['number']]['manrs'] = asn['manrs']


    def get_as_name(self, asn):
        if asn in self.asns:
            return(self.asns[asn]["as_name"])
        else:
            return("Name not available")

    def get_as_country(self, asn):
        if asn in self.asns:
            return(self.asns[asn]["country"])
        else:
            return("ZZ")

    def is_manrs_participant(self, asn):
        if self.manrs_data == True:
            if asn in self.asns:
                return(self.asns[asn]["manrs"])
            else:
                return(False)
        else:
            return("No MANRS Data available")

    def asns_per_country(self, country):
        if re.match("^[A-Z]{2}$", country):
            output = {}
        
            for asn in self.asns:
                if self.asns[asn]['country'] == country:
                    output[asn] = self.asns[asn]
        
            return(output)
        else:
            raise Exception("Country should be in ISO 2-letter format, all uppercase")



#!/usr/bin/env python3
# Copyright (c) 2020-2023, Massimiliano Stucchi
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this
#   list of conditions and the following disclaimer.
#
#2. Redistributions in binary form must reproduce the above copyright notice,
#   this list of conditions and the following disclaimer in the documentation
#   and/or other materials provided with the distribution.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
#DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
#FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
#DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
#SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
#OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.



import asn_info
version = asn_info.__version__

import codecs
import os
import sys

from os.path import abspath, dirname, join
from setuptools import setup, find_packages

here = abspath(dirname(__file__))


def parse_requirements(filename):
    """ load requirements from a pip requirements file """
    lineiter = (line.strip() for line in open(filename))
    return [line for line in lineiter if line and not line.startswith("#")]

with codecs.open(join(here, 'README.md'), encoding='utf-8') as f:
    README = f.read()

if sys.argv[-1] == 'publish':
    os.system('python3 setup.py sdist upload')
    print("You probably want to also tag the version now:")
    print(("  git tag -a %s -m 'version %s'" % (version, version)))
    print("  git push --tags")
    sys.exit()

install_reqs = parse_requirements('requirements.txt')
reqs = install_reqs

setup(
    name='asn_info',
    version=version,
    maintainer="Massimiliano Stucchi",
    maintainer_email='max@stucchi.ch',
    url='https://github.com/stucchimax/asn_info',
    description='A python library providing information about ASNs (AS Name, Country and MANRS membership)',
    long_description=README,
    long_description_content_type="text/markdown",
    license='BSD',
    keywords='asn autonomous systems routing networking',
    setup_requires=reqs,
    install_requires=reqs,
    classifiers=[
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: System :: Networking',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 3 :: Only'
    ],
    packages=find_packages(exclude=['tests', 'tests.*']),
)
